# tap-s3-csv

This is a [Singer](https://singer.io) tap that produces JSON-formatted data following the [Singer spec](https://github.com/singer-io/getting-started/blob/master/SPEC.md).

---

Copyright &copy; 2018 Stitch
